@@ -1,13 +1,13 @@
 package Moose::Meta::Attribute::Native::MethodProvider::Code;
 use Moose::Role;
 
-our $VERSION   = '0.92';
+our $VERSION   = '0.93';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
 sub execute : method {
     my ( $attr, $reader, $writer ) = @_;
-    return sub { $reader->(@_)->(@_) };
+    return sub { my ($self, @args) = @_; $reader->($self)->(@args) };
 }
 
 no Moose::Role;
