@@ -6,7 +6,7 @@ use warnings;
 
 use Scalar::Util 'blessed', 'weaken', 'looks_like_number', 'refaddr';
 
-our $VERSION   = '0.92';
+our $VERSION   = '0.93';
 our $AUTHORITY = 'cpan:STEVAN';
 
 use base 'Moose::Meta::Method',
@@ -57,9 +57,6 @@ sub _initialize_body {
     my $source = 'sub {';
     $source .= "\n" . 'my $_instance = shift;';
 
-    $source .= "\n" . q{Carp::cluck 'Calling new() on an instance is deprecated,'
-                        . ' please use (blessed $obj)->new' if Scalar::Util::blessed($_instance);};
-
     $source .= "\n" . 'my $class = Scalar::Util::blessed($_instance) || $_instance;';
 
     $source .= "\n" . 'return $class->Moose::Object::new(@_)';
