@@ -7,7 +7,7 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken';
 
-our $VERSION   = '0.92';
+our $VERSION   = '0.93';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -104,8 +104,8 @@ sub _initialize_body {
                 object      => $instance
             );
         }
-        my @args = (@{ $self->curried_arguments }, @_);
-        $proxy->$method_to_call(@args);
+        unshift @_, @{ $self->curried_arguments };
+        $proxy->$method_to_call(@_);
     };
 }
 
